@@ -16,6 +16,7 @@
 from .version import __version__
 
 from . import log
+from . import collection_managers
 from . import generators
 from . import simulation
 from . import parsers
@@ -27,6 +28,7 @@ from .path import Path
 
 __all__ = [
     __version__,
+    'collection_managers',
     'log',
     'generators',
     'simulation',
