@@ -17,20 +17,15 @@ policy rules for object placement and constraints.
 """
 
 from .world_generator import WorldGenerator
-from .collision_checker import SingletonCollisionChecker, CollisionChecker
-from .assets_manager import AssetsManager
-from .engine_manager import EngineManager
-from .constraints_manager import ConstraintsManager
-from .model_group_generator import ModelGroupGenerator
-from .rules_manager import RulesManager
+from .collision_checker import SingletonCollisionChecker, \
+    CollisionChecker  # noqa: F401
+from .model_group_generator import ModelGroupGenerator  # noqa: F401
+from .heightmap_generator import HeightmapGenerator
 
 __all__ = [
     'WorldGenerator',
     'SingletonCollisionChecker',
-    'CollisionChecker',
-    'AssetsManager',
-    'EngineManager',
-    'ConstraintsManager',
+    'CollisionChecker'
     'ModelGroupGenerator',
-    'RulesManager'
+    'HeightmapGenerator',
 ]
