@@ -13,7 +13,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 from .rule import Rule
-from ..constraints_manager import ConstraintsManager
+from ...collection_managers import ConstraintsManager
 from ...utils import is_string, is_boolean
 from ...simulation.properties import Pose
 
@@ -62,7 +62,7 @@ class WithinWorkspace(Rule):
                 assert is_boolean(value[tag]), \
                     'DOF element <{}> must be a boolean, ' \
                     'received={}, type={}'.format(
-                        value[tag], type(value[tag]))
+                        tag, value[tag], type(value[tag]))
                 self._dofs[tag] = value[tag]
 
     @property
