@@ -21,7 +21,7 @@ class Background(XMLVector):
     _TYPE = 'sdf'
 
     def __init__(self, default=[0, 0, 0, 1]):
-        XMLVector.__init__(self, 4)
+        super(Background, self).__init__(4)
         self._default = default
         self._value = default
 
