@@ -20,4 +20,4 @@ class CFMDamping(XMLBoolean):
     _TYPE = 'sdf'
 
     def __init__(self, default=False):
-        XMLBoolean.__init__(self, default)
+        super(CFMDamping, self).__init__(default)
