@@ -20,7 +20,7 @@ class Constant(XMLScalar):
     _TYPE = 'sdf'
 
     def __init__(self, default=0):
-        XMLScalar.__init__(self, default)
+        super(Constant, self).__init__(default)
 
     def _set_value(self, value):
         assert self._is_scalar(value), \
