@@ -21,4 +21,4 @@ class Damping(XMLScalar):
     _TYPE = 'sdf'
 
     def __init__(self, default=0):
-        XMLScalar.__init__(self, default, min_value=0)
+        super(Damping, self).__init__(default, min_value=0)
