@@ -21,4 +21,4 @@ class DelayStart(XMLScalar):
     _TYPE = 'sdf'
 
     def __init__(self, default=0):
-        XMLScalar.__init__(self, default)
+        super(DelayStart, self).__init__(default)
