@@ -20,7 +20,7 @@ class Density(XMLScalar):
     _TYPE = 'sdf'
 
     def __init__(self, default=0):
-        XMLScalar.__init__(self, default)
+        super(Density, self).__init__(default)
 
     def _set_value(self, value):
         assert value >= 0.0, '[{}] Input must be equal' \
