@@ -21,4 +21,4 @@ class Filename(XMLString):
     _TYPE = 'sdf'
 
     def __init__(self, default='none'):
-        XMLString.__init__(self, default)
+        super(Filename, self).__init__(default)
