@@ -21,4 +21,4 @@ class Height(XMLScalar):
     _TYPE = 'sdf'
 
     def __init__(self, default=1):
-        XMLScalar.__init__(self, default, min_value=0)
+        super(Height, self).__init__(default, min_value=0)
