@@ -21,12 +21,5 @@ class MinDepth(XMLScalar):
     _TYPE = 'sdf'
 
     def __init__(self, default=0):
-        XMLScalar.__init__(self, default)
-
-    def _set_value(self, value):
-        assert self._is_scalar(value), \
-            'Input value for {} must be a scalar'.format(self._NAME)
-        assert value >= 0, \
-            'Input value for {} must be equal'\
-            ' or greater than zero'.format(self._NAME)
-        XMLScalar._set_value(self, value)
+        super(MinDepth, self).__init__(
+            default, min_value=0)
