@@ -30,7 +30,7 @@ class Mu2(XMLScalar):
     _TYPE = 'sdf'
 
     def __init__(self, default=1):
-        XMLScalar.__init__(self, default)
+        super(Mu2, self).__init__(default)
 
     def _set_value(self, value):
         assert self._is_scalar(value), \
