@@ -21,4 +21,4 @@ class MustBeLoopJoint(XMLBoolean):
     _TYPE = 'sdf'
 
     def __init__(self, default=False):
-        XMLBoolean.__init__(self, default)
+        super(MustBeLoopJoint, self).__init__(default)
