@@ -21,9 +21,5 @@ class PreConIters(XMLInteger):
     _TYPE = 'sdf'
 
     def __init__(self, default=0):
-        XMLInteger.__init__(self, default)
-
-    def _set_value(self, value):
-        assert isinstance(value, int)
-        assert value >= 0
-        XMLInteger._set_value(self, value)
+        super(PreConIters, self).__init__(
+            default, min_value=0)
