@@ -21,4 +21,4 @@ class SplitImpulse(XMLBoolean):
     _TYPE = 'sdf'
 
     def __init__(self, default=True):
-        XMLBoolean.__init__(self, default)
+        super(SplitImpulse, self).__init__(default)
