@@ -21,4 +21,5 @@ class SplitImpulsePenetrationThreshold(XMLScalar):
     _TYPE = 'sdf'
 
     def __init__(self, default=-0.01):
-        XMLScalar.__init__(self, default)
+        super(SplitImpulsePenetrationThreshold, self).__init__(
+            default)
