@@ -21,4 +21,4 @@ class Static(XMLBoolean):
     _TYPE = 'sdf'
 
     def __init__(self, default=False):
-        XMLBoolean.__init__(self, default)
+        super(Static, self).__init__(default)
