@@ -21,8 +21,5 @@ class StaticFriction(XMLScalar):
     _TYPE = 'sdf'
 
     def __init__(self, default=0.9):
-        XMLScalar.__init__(self, default)
-
-    def _set_value(self, value):
-        assert value >= 0
-        XMLScalar._set_value(self, value)
+        super(StaticFriction, self).__init__(
+            default, min_value=0)
