@@ -19,6 +19,7 @@ from .bounding_box import BoundingBox
 from .collision import Collision
 from .footprint import Footprint
 from .geometry import Geometry
+from .heightmap import Heightmap
 from .inertial import Inertial
 from .visual import Visual
 from .material import Material
@@ -27,6 +28,7 @@ from .noise import Noise
 from .plugin import Plugin
 from .pose import Pose
 from .script import Script
+from .texture import Texture
 from .trajectory import Trajectory
 from .waypoint import Waypoint
 
@@ -38,6 +40,7 @@ __all__ = [
     'Collision',
     'Footprint',
     'Geometry',
+    'Heightmap',
     'Inertial',
     'Visual',
     'Material',
@@ -46,6 +49,7 @@ __all__ = [
     'Plugin',
     'Pose',
     'Script',
+    'Texture',
     'Trajectory',
     'Waypoint'
 ]
