@@ -61,7 +61,7 @@ class Collision(object):
             bounce=False,
             contact=False
         )
-        self._geometry = Geometry()
+        self._geometry = Geometry(link_element='collision')
         self._pose = Pose()
 
         # Setting the input parameters
@@ -345,7 +345,8 @@ class Collision(object):
                 if self.sdf.surface is None:
                     self.sdf.surface = create_sdf_element('surface')
                 if self.sdf.surface.friction is None:
-                    self.sdf.surface.friction = create_sdf_element('friction')
+                    self.sdf.surface.friction = create_sdf_element(
+                        'friction', 'surface')
                 if self.sdf.surface.friction.ode is None:
                     ode = create_sdf_element('ode', 'collision')
                     self.sdf.surface.friction.ode = ode
@@ -442,7 +443,8 @@ class Collision(object):
                 if self.sdf.surface is None:
                     self.sdf.surface = create_sdf_element('surface')
                 if self.sdf.surface.friction is None:
-                    self.sdf.surface.friction = create_sdf_element('friction')
+                    self.sdf.surface.friction = create_sdf_element(
+                        'friction', 'surface')
                 if self.sdf.surface.friction.bullet is None:
                     bullet = create_sdf_element('bullet', 'collision')
                     self.sdf.surface.friction.bullet = bullet
@@ -621,13 +623,13 @@ class Collision(object):
         collision = create_sdf_element('collision', 'link')
         collision.name = self.name
         if len(resource_prefix) == 0:
-            mesh_filename = self.name
+            filename = self.name
         else:
-            mesh_filename = '{}_{}'.format(
+            filename = '{}_{}'.format(
                 resource_prefix,
                 self.name)
         collision.geometry = self._geometry.to_sdf(
-            mesh_filename=mesh_filename,
+            filename=filename,
             model_folder=model_folder,
             copy_resources=copy_resources)
         if self.using_property('pose'):
